==> maemo-sdk-rootstrap_3.0_armel.tgz: usr/src/rx-34-kernel-headers/include/asm-arm/arch-omap/mailbox.h <==
/* mailbox.h */

#ifndef MAILBOX_H
#define MAILBOX_H

#include <linux/wait.h>
#include <linux/workqueue.h>
#include <linux/blkdev.h>

typedef u32 mbox_msg_t;
typedef void (mbox_receiver_t)(mbox_msg_t msg);
struct omap_mbox;

typedef int __bitwise omap_mbox_irq_t;
#define IRQ_TX ((__force omap_mbox_irq_t) 1)
#define IRQ_RX ((__force omap_mbox_irq_t) 2)

typedef int __bitwise omap_mbox_type_t;
#define OMAP_MBOX_TYPE1 ((__force omap_mbox_type_t) 1)
#define OMAP_MBOX_TYPE2 ((__force omap_mbox_type_t) 2)

struct omap_mbox_ops {
	omap_mbox_type_t type;
	int		(*startup)(struct omap_mbox *);
	void		(*shutdown)(struct omap_mbox *);
	/* fifo */
	mbox_msg_t	(*fifo_read)(struct omap_mbox *);
	void		(*fifo_write)(struct omap_mbox *, mbox_msg_t);
	int		(*fifo_empty)(struct omap_mbox *);
	int		(*fifo_full)(struct omap_mbox *);
	/* irq */
	void		(*enable_irq)(struct omap_mbox *, omap_mbox_irq_t);
	void		(*disable_irq)(struct omap_mbox *, omap_mbox_irq_t);
	void		(*ack_irq)(struct omap_mbox *, omap_mbox_irq_t);
	int		(*is_irq)(struct omap_mbox *, omap_mbox_irq_t);
};

struct omap_mbox {
	char			*name;
	spinlock_t		 lock;
	unsigned int		 irq;

	struct workqueue_struct	*workq;
	struct work_struct	msg_receive;

	request_queue_t		*txq, *rxq;

	mbox_msg_t		 seq_snd, seq_rcv;
	struct class_device	 class_dev;

	void	(*msg_receive_cb)(mbox_msg_t);
	int	(*msg_sender_cb)(void*);

	struct omap_mbox_ops	*ops;

	struct omap_mbox	*next;
	void			*priv;

	void			(*err_notify)(void);
};

int omap_mbox_msg_send(struct omap_mbox *, mbox_msg_t msg, void *);

struct omap_mbox *omap_mbox_get(const char *);
void omap_mbox_put(struct omap_mbox *);

int omap_mbox_register(struct omap_mbox *);
int omap_mbox_unregister(struct omap_mbox *);

void omap_mbox_init_seq(struct omap_mbox *);

#endif /* MAILBOX_H */

==> maemo-sdk-rootstrap_3.1_armel.tgz: usr/src/rx-34-kernel-headers/include/asm-arm/arch-omap/mailbox.h <==
/* mailbox.h */

#ifndef MAILBOX_H
#define MAILBOX_H

#include <linux/wait.h>
#include <linux/workqueue.h>
#include <linux/blkdev.h>

typedef u32 mbox_msg_t;
typedef void (mbox_receiver_t)(mbox_msg_t msg);
struct omap_mbox;

typedef int __bitwise omap_mbox_irq_t;
#define IRQ_TX ((__force omap_mbox_irq_t) 1)
#define IRQ_RX ((__force omap_mbox_irq_t) 2)

typedef int __bitwise omap_mbox_type_t;
#define OMAP_MBOX_TYPE1 ((__force omap_mbox_type_t) 1)
#define OMAP_MBOX_TYPE2 ((__force omap_mbox_type_t) 2)

struct omap_mbox_ops {
	omap_mbox_type_t type;
	int		(*startup)(struct omap_mbox *);
	void		(*shutdown)(struct omap_mbox *);
	/* fifo */
	mbox_msg_t	(*fifo_read)(struct omap_mbox *);
	void		(*fifo_write)(struct omap_mbox *, mbox_msg_t);
	int		(*fifo_empty)(struct omap_mbox *);
	int		(*fifo_full)(struct omap_mbox *);
	/* irq */
	void		(*enable_irq)(struct omap_mbox *, omap_mbox_irq_t);
	void		(*disable_irq)(struct omap_mbox *, omap_mbox_irq_t);
	void		(*ack_irq)(struct omap_mbox *, omap_mbox_irq_t);
	int		(*is_irq)(struct omap_mbox *, omap_mbox_irq_t);
};

struct omap_mbox_queue {
	spinlock_t		lock;
	request_queue_t		*queue;
	struct work_struct	work;
	int			(*callback)(void *);
};

struct omap_mbox {
	char			*name;
	unsigned int		 irq;

	struct omap_mbox_queue	*txq, *rxq;

	mbox_msg_t		 seq_snd, seq_rcv;
	struct class_device	 class_dev;

	struct omap_mbox_ops	*ops;

	struct omap_mbox	*next;
	void			*priv;

	void			(*err_notify)(void);
};

int omap_mbox_msg_send(struct omap_mbox *, mbox_msg_t msg, void *);

struct omap_mbox *omap_mbox_get(const char *);
void omap_mbox_put(struct omap_mbox *);

int omap_mbox_register(struct omap_mbox *);
int omap_mbox_unregister(struct omap_mbox *);

void omap_mbox_init_seq(struct omap_mbox *);

#endif /* MAILBOX_H */
